==> seedsui-react-5.5.92.tgz: package/lib/Jcrop/原代码/shade.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); Object.defineProperty(subClass, "prototype", { writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

import Rect from "./rect";
import DomObj from "./domobj";

var Manager = /*#__PURE__*/function () {
  function Manager(el) {
    _classCallCheck(this, Manager);

    if (typeof el === 'string') el = document.getElementById(el);
    this.el = el;
    this.shades = {};
  }

  _createClass(Manager, [{
    key: "init",
    value: function init() {
      var _this = this;

      var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      this.active = options.shade !== undefined ? options.shade : true;
      this.keys().forEach(function (key) {
        _this.shades[key] = Shade.create(options, key);
      });
      this.el.addEventListener('crop.update', function (e) {
        if (e.cropTarget.isActive() && e.cropTarget.options.shade) {
          _this.adjust(e.cropTarget.pos);
        }
      }, false);
      this.enable();
    }
  }, {
    key: "adjust",
    value: function adjust(rect) {
      var f = Rect.from(this.el);
      var s = this.shades;
      s.t.h = rect.y;
      s.b.h = f.h - rect.y2;
      s.t.w = s.b.w = Math.floor(rect.w);
      s.l.w = s.t.x = s.b.x = Math.ceil(rect.x);
      s.r.w = f.w - (Math.ceil(rect.x) + Math.floor(rect.w));
    }
  }, {
    key: "keys",
    value: function keys() {
      return ['t', 'l', 'r', 'b'];
    }
  }, {
    key: "enable",
    value: function enable() {
      var _this2 = this;

      var s = this.shades;
      this.keys().forEach(function (key) {
        return s[key].insert(_this2.el);
      });
    }
  }, {
    key: "disable",
    value: function disable() {
      var s = this.shades;
      this.keys().forEach(function (key) {
        return s[key].remove();
      });
    }
  }, {
    key: "setStyle",
    value: function setStyle(color, opacity) {
      var s = this.shades;
      this.keys().forEach(function (key) {
        return s[key].color(color).opacity(opacity);
      });
    }
  }]);

  return Manager;
}();

Manager.attach = function (i) {
  var el = i.el;
  var m = new Manager(el);
  m.init(i.options);
  i.shades = m;

  i._optconf['shade'] = function (v) {
    return i.updateShades();
  };

  i._optconf['shadeColor'] = function (v) {
    return m.setStyle(v);
  };

  i._optconf['shadeOpacity'] = function (v) {
    return m.setStyle(null, v);
  };

  return m;
};

var Shade = /*#__PURE__*/function (_DomObj) {
  _inherits(Shade, _DomObj);

  var _super = _createSuper(Shade);

  function Shade() {
    _classCallCheck(this, Shade);

    return _super.apply(this, arguments);
  }

  _createClass(Shade, [{
    key: "insert",
    value: function insert(el) {
      el.appendChild(this.el);
    }
  }, {
    key: "remove",
    value: function remove() {
      this.el.remove();
    }
  }, {
    key: "w",
    set: function set(w) {
      this.el.style.width = w + 'px';
    }
  }, {
    key: "h",
    set: function set(h) {
      this.el.style.height = h + 'px';
    }
  }, {
    key: "x",
    set: function set(l) {
      this.el.style.left = l + 'px';
    }
  }, {
    key: "color",
    value: function color(c) {
      if (c) this.el.style.backgroundColor = c;
      return this;
    }
  }, {
    key: "opacity",
    value: function opacity(o) {
      if (o) this.el.style.opacity = o;
      return this;
    }
  }]);

  return Shade;
}(DomObj);

Shade.create = function (o, key) {
  var el = document.createElement('div');
  var clname = o.shadeClass || 'jcrop-shade';
  el.className = "".concat(clname, " ").concat(key);
  var obj = new Shade(el);
  return obj.color(o.shadeColor).opacity(o.shadeOpacity);
};

Shade.Manager = Manager;
export default Shade;

==> seedsui-react-5.6.60.tgz: package/lib/Jcrop/原代码/shade.js <==
function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); Object.defineProperty(subClass, "prototype", { writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }
function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }
function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }
function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }
function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }
function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }
function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
import Rect from "./rect";
import DomObj from "./domobj";
var Manager = /*#__PURE__*/function () {
  function Manager(el) {
    _classCallCheck(this, Manager);
    if (typeof el === 'string') el = document.getElementById(el);
    this.el = el;
    this.shades = {};
  }
  _createClass(Manager, [{
    key: "init",
    value: function init() {
      var _this = this;
      var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
      this.active = options.shade !== undefined ? options.shade : true;
      this.keys().forEach(function (key) {
        _this.shades[key] = Shade.create(options, key);
      });
      this.el.addEventListener('crop.update', function (e) {
        if (e.cropTarget.isActive() && e.cropTarget.options.shade) {
          _this.adjust(e.cropTarget.pos);
        }
      }, false);
      this.enable();
    }
  }, {
    key: "adjust",
    value: function adjust(rect) {
      var f = Rect.from(this.el);
      var s = this.shades;
      s.t.h = rect.y;
      s.b.h = f.h - rect.y2;
      s.t.w = s.b.w = Math.floor(rect.w);
      s.l.w = s.t.x = s.b.x = Math.ceil(rect.x);
      s.r.w = f.w - (Math.ceil(rect.x) + Math.floor(rect.w));
    }
  }, {
    key: "keys",
    value: function keys() {
      return ['t', 'l', 'r', 'b'];
    }
  }, {
    key: "enable",
    value: function enable() {
      var _this2 = this;
      var s = this.shades;
      this.keys().forEach(function (key) {
        return s[key].insert(_this2.el);
      });
    }
  }, {
    key: "disable",
    value: function disable() {
      var s = this.shades;
      this.keys().forEach(function (key) {
        return s[key].remove();
      });
    }
  }, {
    key: "setStyle",
    value: function setStyle(color, opacity) {
      var s = this.shades;
      this.keys().forEach(function (key) {
        return s[key].color(color).opacity(opacity);
      });
    }
  }]);
  return Manager;
}();
Manager.attach = function (i) {
  var el = i.el;
  var m = new Manager(el);
  m.init(i.options);
  i.shades = m;
  i._optconf['shade'] = function (v) {
    return i.updateShades();
  };
  i._optconf['shadeColor'] = function (v) {
    return m.setStyle(v);
  };
  i._optconf['shadeOpacity'] = function (v) {
    return m.setStyle(null, v);
  };
  return m;
};
var Shade = /*#__PURE__*/function (_DomObj) {
  _inherits(Shade, _DomObj);
  var _super = _createSuper(Shade);
  function Shade() {
    _classCallCheck(this, Shade);
    return _super.apply(this, arguments);
  }
  _createClass(Shade, [{
    key: "insert",
    value: function insert(el) {
      el.appendChild(this.el);
    }
  }, {
    key: "remove",
    value: function remove() {
      this.el.remove();
    }
  }, {
    key: "w",
    set: function set(w) {
      this.el.style.width = w + 'px';
    }
  }, {
    key: "h",
    set: function set(h) {
      this.el.style.height = h + 'px';
    }
  }, {
    key: "x",
    set: function set(l) {
      this.el.style.left = l + 'px';
    }
  }, {
    key: "color",
    value: function color(c) {
      if (c) this.el.style.backgroundColor = c;
      return this;
    }
  }, {
    key: "opacity",
    value: function opacity(o) {
      if (o) this.el.style.opacity = o;
      return this;
    }
  }]);
  return Shade;
}(DomObj);
Shade.create = function (o, key) {
  var el = document.createElement('div');
  var clname = o.shadeClass || 'jcrop-shade';
  el.className = "".concat(clname, " ").concat(key);
  var obj = new Shade(el);
  return obj.color(o.shadeColor).opacity(o.shadeOpacity);
};
Shade.Manager = Manager;
export default Shade;
